summaryrefslogtreecommitdiffstats
path: root/src/nlmsg.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/nlmsg.c')
-rw-r--r--src/nlmsg.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/nlmsg.c b/src/nlmsg.c
index ad387e7..274aa8e 100644
--- a/src/nlmsg.c
+++ b/src/nlmsg.c
@@ -38,12 +38,12 @@ size_t mnl_nlmsg_aligned_size(int len)
}
/**
* mnl_nlmsg_payload_size - get the size of the payload
* @nlh: pointer to the header of the netlink message
*
* This function returns the size of the netlink payload
*/
-size_t mnl_nlmsg_payload_size(const struct nlmsghdr *nlh)
+size_t mnl_nlmsg_get_payload_len(const struct nlmsghdr *nlh)
{
return nlh->nlmsg_len - MNL_NLMSG_HDRLEN;
}
@@ -38,12 +38,12 @@ size_t mnl_nlmsg_aligned_size(int len)
}
/**
- * mnl_nlmsg_payload_size - get the size of the payload
+ * mnl_nlmsg_get_payload_len - get the size of the payload
* @nlh: pointer to the header of the netlink message
*